@@ -49,20 +49,15 @@
 
 package com.openexchange.ajp13.servlet.http;
 
-import java.io.IOException;
 import java.security.Principal;
 import java.text.ParseException;
-import java.util.Collection;
 import javax.servlet.ServletContext;
-import javax.servlet.ServletException;
 import javax.servlet.http.Cookie;
 import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
 import javax.servlet.http.HttpSession;
-import javax.servlet.http.Part;
 import com.openexchange.ajp13.AJPv13RequestHandler;
-import com.openexchange.ajp13.AJPv13ServiceRegistry;
+import com.openexchange.ajp13.Services;
 import com.openexchange.ajp13.exception.AJPv13Exception;
 import com.openexchange.ajp13.servlet.ServletConfigLoader;
 import com.openexchange.ajp13.servlet.ServletRequestWrapper;
@@ -211,9 +206,7 @@ public class HttpServletRequestWrapper extends ServletRequestWrapper implements
 
     @Override
     public boolean isUserInRole(final String role) {
-        if (LOG.isWarnEnabled()) {
-            LOG.warn("Method isUserInRole() is not implemented in HttpServletRequestWrapper, yet!");
-        }
+        LOG.warn("Method isUserInRole() is not implemented in HttpServletRequestWrapper, yet!");
         return false;
     }
 
@@ -296,8 +289,8 @@ public class HttpServletRequestWrapper extends ServletRequestWrapper implements
         /*
          * First look-up HttpSessionManagement if a session already exists
          */
-        final Cookie sessionCookie = ajpRequestHandler.getHttpSessionCookie();
-        final String httpSessionId = sessionCookie.getValue();
+        final Cookie jsessionIdCookie = ajpRequestHandler.getHttpSessionCookie();
+        final String httpSessionId = jsessionIdCookie.getValue();
         final HttpSessionWrapper httpSession = HttpSessionManagement.getHttpSession(httpSessionId);
         if (httpSession != null) {
             if (!HttpSessionManagement.isHttpSessionExpired(httpSession)) {
@@ -330,25 +323,25 @@ public class HttpServletRequestWrapper extends ServletRequestWrapper implements
             /*
              * Add JSESSIONID cookie
              */
-            configureCookie(sessionCookie);
-            ajpRequestHandler.getServletResponse().addCookie(sessionCookie);
+            configureCookie(jsessionIdCookie);
+            ajpRequestHandler.getServletResponse().addCookie(jsessionIdCookie);
         }
         return session;
     }
 
     private static final String DEFAULT_PATH = "/";
 
-    private static void configureCookie(final Cookie sessionCookie) {
-        sessionCookie.setPath(DEFAULT_PATH);
-        final ConfigurationService configurationService = AJPv13ServiceRegistry.getInstance().getService(ConfigurationService.class);
+    private static void configureCookie(final Cookie jsessionIdCookie) {
+        jsessionIdCookie.setPath(DEFAULT_PATH);
+        final ConfigurationService configurationService = Services.getService(ConfigurationService.class);
         /*
          * Check if auto-login is enabled
          */
         if (null != configurationService && configurationService.getBoolProperty("com.openexchange.sessiond.autologin", false)) {
-            final int maxAge = (int) (ConfigTools.parseTimespan(configurationService.getProperty("com.openexchange.cookie.ttl", "1W")) / 1000);
-            sessionCookie.setMaxAge(maxAge);
+            final int maxAge = ConfigTools.parseTimespanSecs(configurationService.getProperty("com.openexchange.cookie.ttl", "1W"));
+            jsessionIdCookie.setMaxAge(maxAge);
         } else {
-            sessionCookie.setMaxAge(-1); // cookies auto-expire
+            jsessionIdCookie.setMaxAge(-1); // cookies auto-expire
         }
     }
 
@@ -402,8 +395,7 @@ public class HttpServletRequestWrapper extends ServletRequestWrapper implements
         }
     }
 
-    @Override
-    public ServletContext getServletContext() {
+    private final ServletContext getServletContext() {
         return ServletConfigLoader.getDefaultInstance().getContext(servletInstance.getClass().getCanonicalName(), servletPath);
     }
 
@@ -411,29 +403,4 @@ public class HttpServletRequestWrapper extends ServletRequestWrapper implements
         this.startTime = currentTimeMillis;
     }
 
-    @Override
-    public boolean authenticate(final HttpServletResponse response) throws IOException, ServletException {
-        return false;
-    }
-
-    @Override
-    public void login(final String username, final String password) throws ServletException {
-        // Empty
-    }
-
-    @Override
-    public void logout() throws ServletException {
-        // Empty
-    }
-
-    @Override
-    public Collection<Part> getParts() throws IOException, ServletException {
-        return null;
-    }
-
-    @Override
-    public Part getPart(final String name) throws IOException, ServletException {
-        return null;
-    }
-
 }
