@@ -49,7 +49,6 @@
 
 package com.openexchange.ajp13.servlet.http;
 
-import java.text.MessageFormat;
 import java.util.ArrayList;
 import java.util.Enumeration;
 import java.util.Iterator;
@@ -60,8 +59,7 @@ import javax.servlet.http.HttpSession;
 import javax.servlet.http.HttpSessionBindingEvent;
 import javax.servlet.http.HttpSessionBindingListener;
 import javax.servlet.http.HttpSessionContext;
-import com.openexchange.ajp13.AJPv13ServiceRegistry;
-import com.openexchange.ajp13.servlet.http.HttpSessionWrapper;
+import com.openexchange.ajp13.Services;
 import com.openexchange.config.ConfigTools;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.java.HashKeyMap;
@@ -88,11 +86,11 @@ public class HttpSessionWrapper implements HttpSession {
             synchronized (HttpSessionWrapper.class) {
                 tmp = cookieTTL;
                 if (tmp < 0) {
-                    final ConfigurationService service = AJPv13ServiceRegistry.getInstance().getService(ConfigurationService.class);
+                    final ConfigurationService service = Services.getService(ConfigurationService.class);
                     if (null == service) {
-                        tmp = (int) ConfigTools.parseTimespan("1W");
+                        tmp = ConfigTools.parseTimespanSecs("1W");
                     } else {
-                        tmp = (int) (ConfigTools.parseTimespan(service.getProperty("com.openexchange.cookie.ttl", "1W")) / 1000);
+                        tmp = ConfigTools.parseTimespanSecs(service.getProperty("com.openexchange.cookie.ttl", "1W"));
                     }
                     cookieTTL = tmp;
                 }
@@ -144,7 +142,7 @@ public class HttpSessionWrapper implements HttpSession {
         /*
          * Max. inactive interval
          */
-        final ConfigurationService service = AJPv13ServiceRegistry.getInstance().getService(ConfigurationService.class);
+        final ConfigurationService service = Services.getService(ConfigurationService.class);
         maxInactiveIntervall = null == service ? 1800 : service.getIntProperty("com.openexchange.servlet.maxInactiveIntervall", 1800); // 30 Minutes
         /*
          * Initialize other stuff
@@ -171,7 +169,7 @@ public class HttpSessionWrapper implements HttpSession {
     }
 
     @Override
-    public Enumeration<String> getAttributeNames() {
+    public Enumeration<?> getAttributeNames() {
         return new IteratorEnumeration(attributes.keySet().iterator());
     }
 
@@ -295,18 +293,18 @@ public class HttpSessionWrapper implements HttpSession {
     public void setMaxInactiveInterval(final int maxInactiveIntervall) {
         final int cookieTTL = getCookieTTL();
         if (maxInactiveIntervall < 0 || maxInactiveIntervall > cookieTTL) {
-            LOG.warn(MessageFormat.format("Specified maxInactiveIntervall is negative or exceeds max. cookie time-to-live. Using max. cookie time-to-live: {0}seconds", cookieTTL));
+            LOG.warn("Specified maxInactiveIntervall is negative or exceeds max. cookie time-to-live. Using max. cookie time-to-live: {}seconds", cookieTTL);
             this.maxInactiveIntervall = cookieTTL;
         } else {
             this.maxInactiveIntervall = maxInactiveIntervall;
         }
     }
 
-    private static class IteratorEnumeration implements Enumeration<String> {
+    private static class IteratorEnumeration implements Enumeration<Object> {
 
-        private final Iterator<String> iter;
+        private final Iterator<?> iter;
 
-        public IteratorEnumeration(final Iterator<String> iter) {
+        public IteratorEnumeration(final Iterator<?> iter) {
             this.iter = iter;
         }
 
@@ -316,7 +314,7 @@ public class HttpSessionWrapper implements HttpSession {
         }
 
         @Override
-        public String nextElement() {
+        public Object nextElement() {
             return iter.next();
         }
     }
