@@ -53,16 +53,24 @@ import java.io.InputStream;
 import java.net.MalformedURLException;
 import java.net.URL;
 import java.util.Enumeration;
+import java.util.EventListener;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.Map;
 import java.util.Set;
 import javax.activation.FileTypeMap;
+import javax.servlet.Filter;
+import javax.servlet.FilterRegistration;
 import javax.servlet.RequestDispatcher;
 import javax.servlet.Servlet;
 import javax.servlet.ServletContext;
 import javax.servlet.ServletException;
-import com.openexchange.version.Version;
+import javax.servlet.ServletRegistration;
+import javax.servlet.ServletRegistration.Dynamic;
+import javax.servlet.SessionCookieConfig;
+import javax.servlet.SessionTrackingMode;
+import javax.servlet.descriptor.JspConfigDescriptor;
+import com.openexchange.server.impl.Version;
 
 /**
  * {@link ServletContextWrapper} - A wrapper class for {@link ServletContext} interface.
@@ -101,7 +109,6 @@ public class ServletContextWrapper implements ServletContext {
         /*
          * Resolve occurrences of "/../" in the normalized path
          */
-        final StringBuilder tmp = new StringBuilder(normalized.length());
         while (true) {
             final int index = normalized.indexOf("/../");
             if (index < 0) {
@@ -114,8 +121,7 @@ public class ServletContextWrapper implements ServletContext {
                 return (null);
             }
             final int index2 = normalized.lastIndexOf('/', index - 1);
-            tmp.setLength(0);
-            normalized = tmp.append(normalized.substring(0, index2)).append(normalized.substring(index + 3)).toString();
+            normalized = normalized.substring(0, index2) + normalized.substring(index + 3);
         }
         /*
          * Return the normalized path
@@ -127,7 +133,7 @@ public class ServletContextWrapper implements ServletContext {
     /**
      * The context attributes for this context.
      */
-    private final Map<String, Object> attributes = new HashMap<String, Object>();
+    final Map<String, Object> attributes = new HashMap<String, Object>();
 
     private String resourceDir;
 
@@ -143,7 +149,7 @@ public class ServletContextWrapper implements ServletContext {
     }
 
     @Override
-    public Enumeration<?> getAttributeNames() {
+    public Enumeration<String> getAttributeNames() {
         return new Enumeration<String>() {
 
             private final Iterator<String> iterator = attributes.keySet().iterator();
@@ -185,7 +191,17 @@ public class ServletContextWrapper implements ServletContext {
 
     @Override
     public int getMajorVersion() {
-        return Version.getInstance().getMajor();
+        // E.g. 6.13.0-Rev5
+        final String version = Version.getVersionString();
+        final int pos = version.indexOf('.');
+        if (pos > 0) {
+            try {
+                return Integer.parseInt(version.substring(0, pos));
+            } catch (final NumberFormatException e) {
+                return OX_SERVLET_MAJOR;
+            }
+        }
+        return OX_SERVLET_MAJOR;
     }
 
     @Override
@@ -195,7 +211,16 @@ public class ServletContextWrapper implements ServletContext {
 
     @Override
     public int getMinorVersion() {
-        return Version.getInstance().getMinor();
+        // E.g. 6.13.0-Rev5
+        final String[] tokens = Version.getVersionString().split("\\.");
+        if (tokens.length < 2) {
+            return OX_SERVLET_MINOR;
+        }
+        try {
+            return Integer.parseInt(tokens[1]);
+        } catch (final NumberFormatException e) {
+            return OX_SERVLET_MINOR;
+        }
     }
 
     @Override
@@ -224,7 +249,7 @@ public class ServletContextWrapper implements ServletContext {
     }
 
     @Override
-    public Set<?> getResourcePaths(final String string) {
+    public Set<String> getResourcePaths(final String string) {
         return null;
     }
 
@@ -244,28 +269,34 @@ public class ServletContextWrapper implements ServletContext {
     }
 
     @Override
-    public Enumeration<?> getServletNames() {
+    public Enumeration<String> getServletNames() {
         return null;
     }
 
     @Override
-    public Enumeration<?> getServlets() {
+    public Enumeration<Servlet> getServlets() {
         return null;
     }
 
     @Override
     public void log(final Exception exception, final String string) {
-        LOG.info(string, exception);
+        if (LOG.isInfoEnabled()) {
+            LOG.info(string, exception);
+        }
     }
 
     @Override
     public void log(final String string) {
-        LOG.info(string);
+        if (LOG.isInfoEnabled()) {
+            LOG.info(string);
+        }
     }
 
     @Override
     public void log(final String string, final Throwable throwable) {
-        LOG.info(string, throwable);
+        if (LOG.isInfoEnabled()) {
+            LOG.info(string, throwable);
+        }
     }
 
     @Override
@@ -278,4 +309,136 @@ public class ServletContextWrapper implements ServletContext {
         attributes.put(name, value);
     }
 
+    @Override
+    public int getEffectiveMajorVersion() {
+        return 0;
+    }
+
+    @Override
+    public int getEffectiveMinorVersion() {
+        // Nothing to do
+        return 0;
+    }
+
+    @Override
+    public boolean setInitParameter(final String name, final String value) {
+        // Nothing to do
+        return false;
+    }
+
+    @Override
+    public Dynamic addServlet(final String servletName, final String className) {
+        return null;
+    }
+
+    @Override
+    public Dynamic addServlet(final String servletName, final Servlet servlet) {
+        return null;
+    }
+
+    @Override
+    public Dynamic addServlet(final String servletName, final Class<? extends Servlet> servletClass) {
+        return null;
+    }
+
+    @Override
+    public <T extends Servlet> T createServlet(final Class<T> clazz) throws ServletException {
+        return null;
+    }
+
+    @Override
+    public ServletRegistration getServletRegistration(final String servletName) {
+        return null;
+    }
+
+    @Override
+    public Map<String, ? extends ServletRegistration> getServletRegistrations() {
+        return null;
+    }
+
+    @Override
+    public javax.servlet.FilterRegistration.Dynamic addFilter(final String filterName, final String className) {
+        return null;
+    }
+
+    @Override
+    public javax.servlet.FilterRegistration.Dynamic addFilter(final String filterName, final Filter filter) {
+        return null;
+    }
+
+    @Override
+    public javax.servlet.FilterRegistration.Dynamic addFilter(final String filterName, final Class<? extends Filter> filterClass) {
+        return null;
+    }
+
+    @Override
+    public <T extends Filter> T createFilter(final Class<T> clazz) throws ServletException {
+        return null;
+    }
+
+    @Override
+    public FilterRegistration getFilterRegistration(final String filterName) {
+        return null;
+    }
+
+    @Override
+    public Map<String, ? extends FilterRegistration> getFilterRegistrations() {
+        return null;
+    }
+
+    @Override
+    public SessionCookieConfig getSessionCookieConfig() {
+        return null;
+    }
+
+    @Override
+    public void setSessionTrackingModes(final Set<SessionTrackingMode> sessionTrackingModes) {
+        // Empty
+    }
+
+    @Override
+    public Set<SessionTrackingMode> getDefaultSessionTrackingModes() {
+        return null;
+    }
+
+    @Override
+    public Set<SessionTrackingMode> getEffectiveSessionTrackingModes() {
+        return null;
+    }
+
+    @Override
+    public void addListener(final String className) {
+        // Empty
+    }
+
+    @Override
+    public <T extends EventListener> void addListener(final T t) {
+        // Empty
+    }
+
+    @Override
+    public void addListener(final Class<? extends EventListener> listenerClass) {
+        // Empty
+    }
+
+    @Override
+    public <T extends EventListener> T createListener(final Class<T> clazz) throws ServletException {
+        return null;
+    }
+
+    @Override
+    public JspConfigDescriptor getJspConfigDescriptor() {
+        return null;
+    }
+
+    @Override
+    public ClassLoader getClassLoader() {
+        return null;
+    }
+
+    @Override
+    public void declareRoles(final String... roleNames) {
+        // Empty
+    }
+
 }
