@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -63,9 +63,13 @@ import java.util.Iterator;
 import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
+import javax.servlet.AsyncContext;
+import javax.servlet.DispatcherType;
 import javax.servlet.RequestDispatcher;
+import javax.servlet.ServletContext;
 import javax.servlet.ServletInputStream;
 import javax.servlet.ServletRequest;
+import javax.servlet.ServletResponse;
 import com.openexchange.ajp13.AJPv13Config;
 import com.openexchange.ajp13.AJPv13ServletInputStream;
 import com.openexchange.ajp13.exception.AJPv13Exception;
@@ -149,7 +153,7 @@ public class ServletRequestWrapper implements ServletRequest {
         attributes = new HashMap<String, Object>(32);
         parameters = new HashKeyMap<String[]>(max > 0 ? max : 64).setGenerator(hashKeyGenerator);
         headers = new HashMap<String, String[]>(16);
-        setHeaderInternal(CONTENT_LENGTH, Integer.toString(-1), false);
+        setHeaderInternal(CONTENT_LENGTH, String.valueOf(-1), false);
     }
 
     /**
@@ -159,7 +163,7 @@ public class ServletRequestWrapper implements ServletRequest {
      * @throws AJPv13Exception If setting <code>Content-Length</code> header fails
      */
     public void setContentLength(final int contentLength) throws AJPv13Exception {
-        setHeaderInternal(CONTENT_LENGTH, Integer.toString(contentLength), false);
+        setHeaderInternal(CONTENT_LENGTH, String.valueOf(contentLength), false);
     }
 
     /**
@@ -291,7 +295,7 @@ public class ServletRequestWrapper implements ServletRequest {
      * @param name The header name
      * @return The header values as an {@link Enumeration}
      */
-    public Enumeration<?> getHeaders(final String name) {
+    public Enumeration<String> getHeaders(final String name) {
         return makeEnumeration(headers.get(name.toLowerCase(Locale.ENGLISH)));
     }
 
@@ -300,7 +304,7 @@ public class ServletRequestWrapper implements ServletRequest {
      *
      * @return The header names as an {@link Enumeration}
      */
-    public Enumeration<?> getHeaderNames() {
+    public Enumeration<String> getHeaderNames() {
         return makeEnumeration(headers.keySet().iterator());
     }
 
@@ -326,12 +330,12 @@ public class ServletRequestWrapper implements ServletRequest {
     }
 
     @Override
-    public Enumeration<?> getParameterNames() {
+    public Enumeration<String> getParameterNames() {
         return makeEnumeration(parameters.keySet().iterator());
     }
 
     @Override
-    public Map<?, ?> getParameterMap() {
+    public Map<String, String[]> getParameterMap() {
         return Collections.unmodifiableMap(parameters);
     }
 
@@ -351,7 +355,7 @@ public class ServletRequestWrapper implements ServletRequest {
     }
 
     @Override
-    public Enumeration<?> getAttributeNames() {
+    public Enumeration<String> getAttributeNames() {
         return makeEnumeration(attributes.keySet().iterator());
     }
 
@@ -412,7 +416,7 @@ public class ServletRequestWrapper implements ServletRequest {
     }
 
     @Override
-    public Enumeration<?> getLocales() {
+    public Enumeration<Locale> getLocales() {
         return null;
     }
 
@@ -662,4 +666,39 @@ public class ServletRequestWrapper implements ServletRequest {
         return clone;
     }
 
+    @Override
+    public ServletContext getServletContext() {
+        return null;
+    }
+
+    @Override
+    public AsyncContext startAsync() throws IllegalStateException {
+        return null;
+    }
+
+    @Override
+    public AsyncContext startAsync(final ServletRequest servletRequest, final ServletResponse servletResponse) throws IllegalStateException {
+        return null;
+    }
+
+    @Override
+    public boolean isAsyncStarted() {
+        return false;
+    }
+
+    @Override
+    public boolean isAsyncSupported() {
+        return false;
+    }
+
+    @Override
+    public AsyncContext getAsyncContext() {
+        return null;
+    }
+
+    @Override
+    public DispatcherType getDispatcherType() {
+        return null;
+    }
+
 }
